Earnings Press Release Numeric — Calcbench API Client documentation

# Earnings Press Release Numeric

Numbers from Earnings Press Releases

class calcbench.press_release.FormatType(value)

  An enumeration.

  Text = 'text'

class calcbench.press_release.PressReleaseData(**kwargs)

  Corresponds to PressReleaseDataWrapper on the server

  cik: str
  date: datetime.datetime
  date_reported: datetime.datetime
  entity_id: int
  entity_name: str
  facts: Sequence[calcbench.press_release.PressReleaseDataPoint]
  filing_type: str
  fiscal_period: int
  fiscal_year: int
  fiscal_year_end_date: datetime.datetime
  ticker: str
  url: str

class calcbench.press_release.PressReleaseDataPoint(**kwargs)

  Corresponds to PressReleaseDataPoint on the server

  UOM: str
  effective_value: decimal.Decimal
  fact_id: int
  format_type: calcbench.press_release.FormatType
  is_instant_value: bool
  period_end: datetime.datetime
  period_start: datetime.datetime
  presentation_order: int
  range_high_value: decimal.Decimal
  reported_value: decimal.Decimal
  sec_filing_id: int
  statement_type: str
  table_id: str

calcbench.press_release.press_release_data(company_identifiers, year, period)
  Return type

    `DataFrame`

calcbench.press_release.press_release_raw(company_identifiers, all_history=False, year=None, period=None)
  Return type

    `Sequence`[`PressReleaseData`]